#
# spec file for package wayland-protocols
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2015 Bjørn Lie, Bryne, Norway.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           wayland-protocols
Version:        1.16
Release:        lp151.1.1
Summary:        Wayland protocols that adds functionality not available in the core protocol
License:        MIT
Group:          Development/Libraries/C and C++
Url:            https://wayland.freedesktop.org/
Source:         https://wayland.freedesktop.org/releases/%{name}-%{version}.tar.xz
Source2:        https://wayland.freedesktop.org/releases/%{name}-%{version}.tar.xz.sig
Source3:        %{name}.keyring
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(wayland-scanner)
BuildArch:      noarch

%description
This package contains Wayland protocols that adds functionality not
available in the Wayland core protocol. Such protocols either adds
completely new functionality, or extends the functionality of some other
protocol either in Wayland core, or some other protocol in
wayland-protocols.

%package devel
Summary:        Wayland protocols that adds functionality not available in the core protocol
Group:          Development/Libraries/C and C++

%description devel
This package contains Wayland protocols that adds functionality not
available in the Wayland core protocol. Such protocols either adds
completely new functionality, or extends the functionality of some other
protocol either in Wayland core, or some other protocol in
wayland-protocols.

%prep
%autosetup

%build
%configure

%install
%make_install

%files devel
%doc README COPYING
%{_datadir}/pkgconfig/%{name}.pc
%{_datadir}/%{name}/

%changelog
* Tue Jul 31 2018 bjorn.lie@gmail.com
- Update to version 1.16:
  * This version includes a new version of the unstable text-input
    protocol. The new version is not compatible with the old
    version. Please check the commit adding the new protocols for
    more details about the introduced changes.
  * The stable xdg-shell protocol got some clarifications about
    expectations regarding state requested by the client and what
    is configured by the compositor.
  * The xdg-output protocol got some clarifications about how
    transforms are handled.
  * The test suite was improved to catch issues detected by
    wayland-scanner.
* Sat Jul  7 2018 bjorn.lie@gmail.com
- Update to version 1.15:
  * This version includes a new unstable protocol that enables
    clients to allow the compositor to draw window decorations.
  * The xdg-shell protocol also saw a fix clarifying the
    requirements for xdg-popup parents.
* Thu May 17 2018 rzl@l2f.inesc-id.pt
- Update to version 1.14:
  * xdg-output: Add name and description events
  * configure.ac: Bump version to 1.14
  * xdg-shell: add enums for tiled window state to toplevel
    configure
* Sun Feb 18 2018 avindra@opensuse.org
- Update to version 1.13:
  * New unstable protocol: Input timestamps, a protocol for
    providing high resolution timestamps to input events. See
    commit 4f789286e4ab7f6fecc2ccb895d79362a9b2382a and protocol
    XML file for details.
- use https urls
* Thu Dec 28 2017 zaitor@opensuse.org
- Update to version 1.12:
  * This version includes the new stable version of the XDG Shell
    protocol. In short, the difference between the XDG Shell stable
    and the last unstable version include (among other things):
  * The base interface and the global exposed via the registry
    changed from zxdg_shell_v6 to xdg_wm_base.
  * Fullscreen semantics were better defined and geometry
    requirements relaxed to allow certain hardware optimizations.
  * The popup positioner was changed to allow positioning against a
    point.
  * The popup semantics was changed to allow future extendability.
  * Toplevel parent-child relationship ambiguities were fixed.
  * Unmap/map semantics were better defined.
  * Various other ambiguities were fixed and documentation in
    general was improved.
- Use autosetup macro, and drop make call, nothing is build anyway.
* Thu Nov  9 2017 aavindraa@gmail.com
- Update to version 1.11:
  * This version includes a new unstable version of the xdg-foreign
    protocol. The new version fixes C++ incompatibility issues
    while making the interface request naming a bit more
    descriptive.
  * Use sysroot prefix for pkgdatadir variable.
- Drop wayland-protocols-sysroot-prefix-fix.patch: Fixed upstream.
- Cleanup with spec-cleaner.
* Sat Sep  9 2017 zaitor@opensuse.org
- Add wayland-protocols-sysroot-prefix-fix.patch: Use sysroot
  prefix for pkgdatadir variable. The pc_sysroot is automatically
  added to cflags and libs but not to 'pkg-config --variable'.
* Tue Aug 22 2017 zaitor@opensuse.org
- Update to version 1.10:
  * This version introduces one new unstable protocol: xdg-output -
    a protocol meant for providing desktop centric concepts related
    to output and monitors to clients. It's for example intended to
    be used by Xwayland to be able to layout outputs on a logical
    pixel grid.
* Thu Jul 13 2017 zaitor@opensuse.org
- Update to version 1.9:
  * Keyboard shortcut inhibitation - a protocol meant for making it
    possible for virtual machine viewers, remote desktop clients
    etc, to be able to forward keyboard combinations such as
    Alt-Tab etc.
  * Xwayland keyboard grabbing - a protocol specifically targeted
    at enabling Xwayland to implement keyboard grabs.
- Update keyring, the previous one had expired.
* Sat Jun 17 2017 zaitor@opensuse.org
- Update to version 1.8:
  * Bumped the linux dmabuf protocol version, introducing a new
    request for creating a buffer from a dmabuf without having to
    wait for an event, as well as an event advertising supported
    fourcc modifiers along with the supported formats.
  * A pkg-config file meant for when wayland-protocols is used as a
    git submodule (or otherwise not installed) was added.
  * Various grammar fixes and clarifications were also included in
    this release.
* Sun Aug 21 2016 jengelh@inai.de
- Update to new upstream release 1.7
  * Includes the new version of the unstable xdg-shell v6 protocol.
  * The protocol have gone through extensive changes to how
    surfaces are created and mapped, and also adds a few features
    that was not possible before:
  - A client can now specify a minimum and/or maximum window
    geometry.
  - A client can now in a declarative manner position popup
    surfaces so that they will be visible to the user, e.g. by
    having them placed within the shell work area.
  - A client can map a popup without a grab; this intended to be
    used for relatively positioned child surfaces that should not
    be automatically dismissed, such as tooltips, and user
    interface elements like "popovers" in GTK+.
* Sat Aug 13 2016 zaitor@opensuse.org
- Update to version 1.6:
  * This release include two new unstable protocols:
  - xdg-foreign: reference a toplevel surface from another client
    and affect window manager relationship.
  - idle-inhibit: inhibit idle behaviour (screen blanking,
    screensaver, etc)
* Fri Jul 22 2016 jengelh@inai.de
- Update to new upstream release 1.5
  * This release include a new unstable version of the tablet
    protocol: tablet-unstable-v2. The new tablet protocol fixes a
    few issues discovered in the first version, and also adds pad
    support.
* Mon May 23 2016 zaitor@opensuse.org
- Update to version 1.4:
  * This release include one new stable protocol extension:
    viewporter.
  * The viewporter porter has previously been known as "wl_scaler"
    and enables a client to crop and scale a surface server side.
    Clients and compositors previously implementing support for
    wl_scaler should adapt accordingly. See the corresponding XML
    file for details.
  * Other changes included in this release are various grammatical
    corrections to the presentation-time, tablet, relative-pointer,
    pointer-constraints, linux-dmabuf, input-method and
    fullscreen-shell protocols.
  * It's now also possible to use autotools build files to install
    on platforms where the host CPU is not recognized.
* Fri Mar 18 2016 zaitor@opensuse.org
- Update to version 1.3:
  * This release include one new unstable protocol extension:
    Tablet support. See the corresponding XML file for details.
* Tue Mar  8 2016 zaitor@opensuse.org
- Update to version 1.2:
  * This release includes the first stable protocol extension:
    Presentation time. See the corresponding XML file for details.
  * Changes to existing protocols include: Pointer constaraints: A
    typo in the documentation was fixed.
* Tue Feb 16 2016 zaitor@opensuse.org
- Update to version 1.1:
  * This release includes two new unstable protocol extensions:
    + Relative pointer events.
    + Pointer constraints (locking and confinement).
  * Changes to existing protocols include:
    + xdg-shell: Added EFL state range reservation.
  * Other improvement include basic testing, which tests that all
    the protocols provided will pass wayland-scanner without any
    errors, and compatibility with older pkg-config versions.
- Add pkgconfig(wayland-scanner) BuildRequires: New dependency.
* Mon Feb  8 2016 jengelh@inai.de
- Add key files
* Thu Dec 17 2015 zaitor@opensuse.org
- Initial packaging (version 1.0) for build.opensuse.org
